==> charts_common-0.5.0.tar.gz: lib/common.dart <==
// Copyright 2018 the Charts project authors. Please see the AUTHORS file
// for details.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

export 'src/chart/bar/bar_chart.dart' show BarChart;
export 'src/chart/bar/bar_label_decorator.dart'
    show BarLabelAnchor, BarLabelDecorator, BarLabelPosition;
export 'src/chart/bar/bar_lane_renderer_config.dart' show BarLaneRendererConfig;
export 'src/chart/bar/bar_renderer.dart'
    show BarRenderer, ImmutableBarRendererElement;
export 'src/chart/bar/bar_renderer_config.dart'
    show
        BarRendererConfig,
        CornerStrategy,
        ConstCornerStrategy,
        NoCornerStrategy;
export 'src/chart/bar/bar_renderer_decorator.dart' show BarRendererDecorator;
export 'src/chart/bar/bar_target_line_renderer.dart' show BarTargetLineRenderer;
export 'src/chart/bar/bar_target_line_renderer_config.dart'
    show BarTargetLineRendererConfig;
export 'src/chart/bar/base_bar_renderer_config.dart'
    show BarGroupingType, BaseBarRendererConfig;
export 'src/chart/cartesian/axis/axis.dart'
    show
        domainAxisKey,
        measureAxisIdKey,
        measureAxisKey,
        Axis,
        NumericAxis,
        OrdinalAxis,
        OrdinalViewport;
export 'src/chart/cartesian/axis/numeric_extents.dart' show NumericExtents;
export 'src/chart/cartesian/axis/draw_strategy/gridline_draw_strategy.dart'
    show GridlineRendererSpec;
export 'src/chart/cartesian/axis/draw_strategy/none_draw_strategy.dart'
    show NoneRenderSpec;
export 'src/chart/cartesian/axis/draw_strategy/small_tick_draw_strategy.dart'
    show SmallTickRendererSpec;
export 'src/chart/cartesian/axis/tick_formatter.dart'
    show SimpleTickFormatterBase, TickFormatter;
export 'src/chart/cartesian/axis/spec/axis_spec.dart'
    show
        AxisSpec,
        LineStyleSpec,
        RenderSpec,
        TextStyleSpec,
        TickLabelAnchor,
        TickLabelJustification,
        TickFormatterSpec;
export 'src/chart/cartesian/axis/spec/bucketing_axis_spec.dart'
    show BucketingAxisSpec, BucketingNumericTickProviderSpec;
export 'src/chart/cartesian/axis/spec/date_time_axis_spec.dart'
    show
        DateTimeAxisSpec,
        DayTickProviderSpec,
        AutoDateTimeTickFormatterSpec,
        AutoDateTimeTickProviderSpec,
        DateTimeEndPointsTickProviderSpec,
        DateTimeTickFormatterSpec,
        DateTimeTickProviderSpec,
        TimeFormatterSpec,
        StaticDateTimeTickProviderSpec;
export 'src/chart/cartesian/axis/spec/end_points_time_axis_spec.dart'
    show EndPointsTimeAxisSpec;
export 'src/chart/cartesian/axis/spec/numeric_axis_spec.dart'
    show
        NumericAxisSpec,
        NumericEndPointsTickProviderSpec,
        NumericTickProviderSpec,
        NumericTickFormatterSpec,
        BasicNumericTickFormatterSpec,
        BasicNumericTickProviderSpec,
        StaticNumericTickProviderSpec;
export 'src/chart/cartesian/axis/spec/ordinal_axis_spec.dart'
    show
        BasicOrdinalTickProviderSpec,
        BasicOrdinalTickFormatterSpec,
        OrdinalAxisSpec,
        OrdinalTickFormatterSpec,
        OrdinalTickProviderSpec,
        StaticOrdinalTickProviderSpec;
export 'src/chart/cartesian/axis/spec/percent_axis_spec.dart'
    show PercentAxisSpec;
export 'src/chart/cartesian/axis/time/date_time_extents.dart'
    show DateTimeExtents;
export 'src/chart/cartesian/axis/time/date_time_tick_formatter.dart'
    show DateTimeTickFormatter;
export 'src/chart/cartesian/axis/spec/tick_spec.dart' show TickSpec;
export 'src/chart/cartesian/cartesian_chart.dart'
    show CartesianChart, NumericCartesianChart, OrdinalCartesianChart;
export 'src/chart/cartesian/cartesian_renderer.dart' show BaseCartesianRenderer;
export 'src/chart/common/base_chart.dart' show BaseChart, LifecycleListener;
export 'src/chart/common/behavior/a11y/a11y_explore_behavior.dart'
    show ExploreModeTrigger;
export 'src/chart/common/behavior/a11y/a11y_node.dart' show A11yNode;
export 'src/chart/common/behavior/a11y/domain_a11y_explore_behavior.dart'
    show DomainA11yExploreBehavior, VocalizationCallback;
export 'src/chart/common/behavior/chart_behavior.dart'
    show
        BehaviorPosition,
        ChartBehavior,
        InsideJustification,
        OutsideJustification;
export 'src/chart/common/behavior/calculation/percent_injector.dart'
    show PercentInjector, PercentInjectorTotalType;
export 'src/chart/common/behavior/domain_highlighter.dart'
    show DomainHighlighter;
export 'src/chart/common/behavior/initial_selection.dart' show InitialSelection;
export 'src/chart/common/behavior/legend/legend.dart'
    show Legend, LegendCellPadding, LegendState, LegendTapHandling;
export 'src/chart/common/behavior/legend/legend_entry.dart' show LegendEntry;
export 'src/chart/common/behavior/legend/legend_entry_generator.dart'
    show LegendEntryGenerator, LegendDefaultMeasure;
export 'src/chart/common/behavior/legend/series_legend.dart' show SeriesLegend;
export 'src/chart/common/behavior/line_point_highlighter.dart'
    show LinePointHighlighter, LinePointHighlighterFollowLineType;
export 'src/chart/common/behavior/range_annotation.dart'
    show
        AnnotationLabelAnchor,
        AnnotationLabelDirection,
        AnnotationLabelPosition,
        AnnotationSegment,
        LineAnnotationSegment,
        RangeAnnotation,
        RangeAnnotationAxisType,
        RangeAnnotationSegment;
export 'src/chart/common/behavior/sliding_viewport.dart' show SlidingViewport;
export 'src/chart/common/behavior/chart_title/chart_title.dart'
    show ChartTitle, ChartTitleDirection;
export 'src/chart/common/behavior/selection/lock_selection.dart'
    show LockSelection;
export 'src/chart/common/behavior/selection/select_nearest.dart'
    show SelectNearest;
export 'src/chart/common/behavior/selection/selection_trigger.dart'
    show SelectionTrigger;
export 'src/chart/common/behavior/slider/slider.dart'
    show Slider, SliderListenerCallback, SliderListenerDragState, SliderStyle;
export 'src/chart/common/behavior/zoom/initial_hint_behavior.dart'
    show InitialHintBehavior;
export 'src/chart/common/behavior/zoom/pan_and_zoom_behavior.dart'
    show PanAndZoomBehavior;
export 'src/chart/common/behavior/zoom/pan_behavior.dart'
    show PanBehavior, PanningCompletedCallback;
export 'src/chart/common/behavior/zoom/panning_tick_provider.dart'
    show PanningTickProviderMode;
export 'src/chart/common/canvas_shapes.dart'
    show CanvasBarStack, CanvasPie, CanvasPieSlice, CanvasRect;
export 'src/chart/common/chart_canvas.dart' show ChartCanvas, FillPatternType;
export 'src/chart/common/chart_context.dart' show ChartContext;
export 'src/chart/common/datum_details.dart'
    show DatumDetails, DomainFormatter, MeasureFormatter;
export 'src/chart/common/processed_series.dart' show ImmutableSeries;
export 'src/chart/common/series_datum.dart' show SeriesDatum, SeriesDatumConfig;
export 'src/chart/common/selection_model/selection_model.dart'
    show SelectionModel, SelectionModelType, SelectionModelListener;
export 'src/chart/common/series_renderer.dart'
    show rendererIdKey, rendererKey, SeriesRenderer;
export 'src/chart/common/series_renderer_config.dart'
    show RendererAttributeKey, SeriesRendererConfig;
export 'src/chart/layout/layout_config.dart' show LayoutConfig, MarginSpec;
export 'src/chart/layout/layout_view.dart'
    show
        LayoutPosition,
        LayoutViewPaintOrder,
        LayoutViewPositionOrder,
        ViewMargin,
        ViewMeasuredSizes;
export 'src/chart/line/line_chart.dart' show LineChart;
export 'src/chart/line/line_renderer.dart' show LineRenderer;
export 'src/chart/line/line_renderer_config.dart' show LineRendererConfig;
export 'src/chart/pie/arc_label_decorator.dart'
    show ArcLabelDecorator, ArcLabelLeaderLineStyleSpec, ArcLabelPosition;
export 'src/chart/pie/arc_renderer.dart' show ArcRenderer;
export 'src/chart/pie/arc_renderer_config.dart' show ArcRendererConfig;
export 'src/chart/pie/pie_chart.dart' show PieChart;
export 'src/chart/scatter_plot/comparison_points_decorator.dart'
    show ComparisonPointsDecorator;
export 'src/chart/scatter_plot/point_renderer.dart'
    show
        boundsLineRadiusPxKey,
        boundsLineRadiusPxFnKey,
        pointSymbolRendererFnKey,
        pointSymbolRendererIdKey,
        PointRenderer;
export 'src/chart/scatter_plot/point_renderer_config.dart'
    show PointRendererConfig;
export 'src/chart/scatter_plot/point_renderer_decorator.dart'
    show PointRendererDecorator;
export 'src/chart/scatter_plot/scatter_plot_chart.dart' show ScatterPlotChart;
export 'src/chart/scatter_plot/symbol_annotation_renderer.dart'
    show SymbolAnnotationRenderer;
export 'src/chart/scatter_plot/symbol_annotation_renderer_config.dart'
    show SymbolAnnotationRendererConfig;
export 'src/chart/time_series/time_series_chart.dart' show TimeSeriesChart;
export 'src/common/color.dart' show Color;
export 'src/common/date_time_factory.dart'
    show DateTimeFactory, LocalDateTimeFactory, UTCDateTimeFactory;
export 'src/common/gesture_listener.dart' show GestureListener;
export 'src/common/graphics_factory.dart' show GraphicsFactory;
export 'src/common/line_style.dart' show LineStyle;
export 'src/common/material_palette.dart' show MaterialPalette;
export 'src/common/performance.dart' show Performance;
export 'src/common/proxy_gesture_listener.dart' show ProxyGestureListener;
export 'src/common/rtl_spec.dart' show RTLSpec, AxisPosition;
export 'src/common/style/material_style.dart' show MaterialStyle;
export 'src/common/style/style_factory.dart' show StyleFactory;
export 'src/common/symbol_renderer.dart'
    show
        CircleSymbolRenderer,
        CylinderSymbolRenderer,
        LineSymbolRenderer,
        PointSymbolRenderer,
        RectSymbolRenderer,
        RoundedRectSymbolRenderer,
        SymbolRenderer;
export 'src/common/text_element.dart'
    show TextElement, TextDirection, MaxWidthStrategy;
export 'src/common/text_measurement.dart' show TextMeasurement;
export 'src/common/text_style.dart' show TextStyle;
export 'src/data/series.dart' show Series, TypedAccessorFn;

==> charts_common-0.6.0.tar.gz: lib/common.dart <==
// Copyright 2018 the Charts project authors. Please see the AUTHORS file
// for details.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

export 'src/chart/bar/bar_chart.dart' show BarChart;
export 'src/chart/bar/bar_label_decorator.dart'
    show BarLabelAnchor, BarLabelDecorator, BarLabelPosition;
export 'src/chart/bar/bar_lane_renderer_config.dart' show BarLaneRendererConfig;
export 'src/chart/bar/bar_renderer.dart'
    show BarRenderer, ImmutableBarRendererElement;
export 'src/chart/bar/bar_renderer_config.dart'
    show
        BarRendererConfig,
        CornerStrategy,
        ConstCornerStrategy,
        NoCornerStrategy;
export 'src/chart/bar/bar_renderer_decorator.dart' show BarRendererDecorator;
export 'src/chart/bar/bar_target_line_renderer.dart' show BarTargetLineRenderer;
export 'src/chart/bar/bar_target_line_renderer_config.dart'
    show BarTargetLineRendererConfig;
export 'src/chart/bar/base_bar_renderer_config.dart'
    show BarGroupingType, BaseBarRendererConfig;
export 'src/chart/cartesian/axis/axis.dart'
    show
        domainAxisKey,
        measureAxisIdKey,
        measureAxisKey,
        Axis,
        NumericAxis,
        OrdinalAxis,
        OrdinalViewport;
export 'src/chart/cartesian/axis/numeric_extents.dart' show NumericExtents;
export 'src/chart/cartesian/axis/draw_strategy/gridline_draw_strategy.dart'
    show GridlineRendererSpec;
export 'src/chart/cartesian/axis/draw_strategy/none_draw_strategy.dart'
    show NoneRenderSpec;
export 'src/chart/cartesian/axis/draw_strategy/small_tick_draw_strategy.dart'
    show SmallTickRendererSpec;
export 'src/chart/cartesian/axis/tick_formatter.dart'
    show SimpleTickFormatterBase, TickFormatter;
export 'src/chart/cartesian/axis/spec/axis_spec.dart'
    show
        AxisSpec,
        LineStyleSpec,
        RenderSpec,
        TextStyleSpec,
        TickLabelAnchor,
        TickLabelJustification,
        TickFormatterSpec;
export 'src/chart/cartesian/axis/spec/bucketing_axis_spec.dart'
    show BucketingAxisSpec, BucketingNumericTickProviderSpec;
export 'src/chart/cartesian/axis/spec/date_time_axis_spec.dart'
    show
        DateTimeAxisSpec,
        DayTickProviderSpec,
        AutoDateTimeTickFormatterSpec,
        AutoDateTimeTickProviderSpec,
        DateTimeEndPointsTickProviderSpec,
        DateTimeTickFormatterSpec,
        DateTimeTickProviderSpec,
        TimeFormatterSpec,
        StaticDateTimeTickProviderSpec;
export 'src/chart/cartesian/axis/spec/end_points_time_axis_spec.dart'
    show EndPointsTimeAxisSpec;
export 'src/chart/cartesian/axis/spec/numeric_axis_spec.dart'
    show
        NumericAxisSpec,
        NumericEndPointsTickProviderSpec,
        NumericTickProviderSpec,
        NumericTickFormatterSpec,
        BasicNumericTickFormatterSpec,
        BasicNumericTickProviderSpec,
        StaticNumericTickProviderSpec;
export 'src/chart/cartesian/axis/spec/ordinal_axis_spec.dart'
    show
        BasicOrdinalTickProviderSpec,
        BasicOrdinalTickFormatterSpec,
        OrdinalAxisSpec,
        OrdinalTickFormatterSpec,
        OrdinalTickProviderSpec,
        StaticOrdinalTickProviderSpec;
export 'src/chart/cartesian/axis/spec/percent_axis_spec.dart'
    show PercentAxisSpec;
export 'src/chart/cartesian/axis/time/date_time_extents.dart'
    show DateTimeExtents;
export 'src/chart/cartesian/axis/time/date_time_tick_formatter.dart'
    show DateTimeTickFormatter;
export 'src/chart/cartesian/axis/spec/tick_spec.dart' show TickSpec;
export 'src/chart/cartesian/cartesian_chart.dart'
    show CartesianChart, NumericCartesianChart, OrdinalCartesianChart;
export 'src/chart/cartesian/cartesian_renderer.dart' show BaseCartesianRenderer;
export 'src/chart/common/base_chart.dart' show BaseChart, LifecycleListener;
export 'src/chart/common/behavior/a11y/a11y_explore_behavior.dart'
    show ExploreModeTrigger;
export 'src/chart/common/behavior/a11y/a11y_node.dart' show A11yNode;
export 'src/chart/common/behavior/a11y/domain_a11y_explore_behavior.dart'
    show DomainA11yExploreBehavior, VocalizationCallback;
export 'src/chart/common/behavior/chart_behavior.dart'
    show
        BehaviorPosition,
        ChartBehavior,
        InsideJustification,
        OutsideJustification;
export 'src/chart/common/behavior/calculation/percent_injector.dart'
    show PercentInjector, PercentInjectorTotalType;
export 'src/chart/common/behavior/domain_highlighter.dart'
    show DomainHighlighter;
export 'src/chart/common/behavior/initial_selection.dart' show InitialSelection;
export 'src/chart/common/behavior/legend/legend.dart'
    show Legend, LegendCellPadding, LegendState, LegendTapHandling;
export 'src/chart/common/behavior/legend/legend_entry.dart' show LegendEntry;
export 'src/chart/common/behavior/legend/legend_entry_generator.dart'
    show LegendEntryGenerator, LegendDefaultMeasure;
export 'src/chart/common/behavior/legend/datum_legend.dart' show DatumLegend;
export 'src/chart/common/behavior/legend/series_legend.dart' show SeriesLegend;
export 'src/chart/common/behavior/line_point_highlighter.dart'
    show LinePointHighlighter, LinePointHighlighterFollowLineType;
export 'src/chart/common/behavior/range_annotation.dart'
    show
        AnnotationLabelAnchor,
        AnnotationLabelDirection,
        AnnotationLabelPosition,
        AnnotationSegment,
        LineAnnotationSegment,
        RangeAnnotation,
        RangeAnnotationAxisType,
        RangeAnnotationSegment;
export 'src/chart/common/behavior/sliding_viewport.dart' show SlidingViewport;
export 'src/chart/common/behavior/chart_title/chart_title.dart'
    show ChartTitle, ChartTitleDirection;
export 'src/chart/common/behavior/selection/lock_selection.dart'
    show LockSelection;
export 'src/chart/common/behavior/selection/select_nearest.dart'
    show SelectNearest;
export 'src/chart/common/behavior/selection/selection_trigger.dart'
    show SelectionTrigger;
export 'src/chart/common/behavior/slider/slider.dart'
    show
        Slider,
        SliderHandlePosition,
        SliderListenerCallback,
        SliderListenerDragState,
        SliderStyle;
export 'src/chart/common/behavior/zoom/initial_hint_behavior.dart'
    show InitialHintBehavior;
export 'src/chart/common/behavior/zoom/pan_and_zoom_behavior.dart'
    show PanAndZoomBehavior;
export 'src/chart/common/behavior/zoom/pan_behavior.dart'
    show PanBehavior, PanningCompletedCallback;
export 'src/chart/common/behavior/zoom/panning_tick_provider.dart'
    show PanningTickProviderMode;
export 'src/chart/common/canvas_shapes.dart'
    show CanvasBarStack, CanvasPie, CanvasPieSlice, CanvasRect;
export 'src/chart/common/chart_canvas.dart' show ChartCanvas, FillPatternType;
export 'src/chart/common/chart_context.dart' show ChartContext;
export 'src/chart/common/datum_details.dart'
    show DatumDetails, DomainFormatter, MeasureFormatter;
export 'src/chart/common/processed_series.dart'
    show ImmutableSeries, MutableSeries;
export 'src/chart/common/series_datum.dart' show SeriesDatum, SeriesDatumConfig;
export 'src/chart/common/selection_model/selection_model.dart'
    show SelectionModel, SelectionModelType, SelectionModelListener;
export 'src/chart/common/series_renderer.dart'
    show rendererIdKey, rendererKey, SeriesRenderer;
export 'src/chart/common/series_renderer_config.dart'
    show RendererAttributeKey, SeriesRendererConfig;
export 'src/chart/layout/layout_config.dart' show LayoutConfig, MarginSpec;
export 'src/chart/layout/layout_view.dart'
    show
        LayoutPosition,
        LayoutView,
        LayoutViewConfig,
        LayoutViewPaintOrder,
        LayoutViewPositionOrder,
        ViewMargin,
        ViewMeasuredSizes;
export 'src/chart/line/line_chart.dart' show LineChart;
export 'src/chart/line/line_renderer.dart' show LineRenderer;
export 'src/chart/line/line_renderer_config.dart' show LineRendererConfig;
export 'src/chart/pie/arc_label_decorator.dart'
    show ArcLabelDecorator, ArcLabelLeaderLineStyleSpec, ArcLabelPosition;
export 'src/chart/pie/arc_renderer.dart' show ArcRenderer;
export 'src/chart/pie/arc_renderer_config.dart' show ArcRendererConfig;
export 'src/chart/pie/pie_chart.dart' show PieChart;
export 'src/chart/scatter_plot/comparison_points_decorator.dart'
    show ComparisonPointsDecorator;
export 'src/chart/scatter_plot/point_renderer.dart'
    show
        boundsLineRadiusPxKey,
        boundsLineRadiusPxFnKey,
        pointSymbolRendererFnKey,
        pointSymbolRendererIdKey,
        PointRenderer;
export 'src/chart/scatter_plot/point_renderer_config.dart'
    show PointRendererConfig;
export 'src/chart/scatter_plot/point_renderer_decorator.dart'
    show PointRendererDecorator;
export 'src/chart/scatter_plot/scatter_plot_chart.dart' show ScatterPlotChart;
export 'src/chart/scatter_plot/symbol_annotation_renderer.dart'
    show SymbolAnnotationRenderer;
export 'src/chart/scatter_plot/symbol_annotation_renderer_config.dart'
    show SymbolAnnotationRendererConfig;
export 'src/chart/time_series/time_series_chart.dart' show TimeSeriesChart;
export 'src/common/color.dart' show Color;
export 'src/common/date_time_factory.dart'
    show DateTimeFactory, LocalDateTimeFactory, UTCDateTimeFactory;
export 'src/common/gesture_listener.dart' show GestureListener;
export 'src/common/graphics_factory.dart' show GraphicsFactory;
export 'src/common/line_style.dart' show LineStyle;
export 'src/common/material_palette.dart' show MaterialPalette;
export 'src/common/performance.dart' show Performance;
export 'src/common/proxy_gesture_listener.dart' show ProxyGestureListener;
export 'src/common/rtl_spec.dart' show AxisDirection, RTLSpec;
export 'src/common/style/material_style.dart' show MaterialStyle;
export 'src/common/style/style_factory.dart' show StyleFactory;
export 'src/common/symbol_renderer.dart'
    show
        CircleSymbolRenderer,
        CylinderSymbolRenderer,
        LineSymbolRenderer,
        PointSymbolRenderer,
        RectSymbolRenderer,
        RoundedRectSymbolRenderer,
        SymbolRenderer;
export 'src/common/text_element.dart'
    show TextElement, TextDirection, MaxWidthStrategy;
export 'src/common/text_measurement.dart' show TextMeasurement;
export 'src/common/text_style.dart' show TextStyle;
export 'src/data/series.dart' show Series, TypedAccessorFn;
